Module: wine
Branch: master
Commit: 89e79d8144308a24676ef069d567a14655985b0c
URL: http://source.winehq.org/git/wine.git/?a=commit;h=89e79d8144308a24676ef069d…
Author: Michael Stefaniuc <mstefani(a)winehq.org>
Date: Thu Sep 28 00:23:41 2017 +0200
tools/sfnt2fon: Just skip all glyphs below 0x20.
Signed-off-by: Michael Stefaniuc <mstefani(a)winehq.org>
Signed-off-by: Alexandre Julliard <julliard(a)winehq.org>
---
tools/sfnt2fon/sfnt2fon.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/dlls/sapi/Makefile.in b/dlls/sapi/Makefile.in
index 99a0143..5303299 100644
--- a/dlls/sapi/Makefile.in
+++ b/dlls/sapi/Makefile.in
@@ -7,3 +7,6 @@ C_SRCS = \
IDL_SRCS = \
sapi_classes.idl \
sapi_typelib.idl
+
+RC_SRCS = \
+ sapi.rc
diff --git a/dlls/sapi/sapi.rc b/dlls/sapi/sapi.rc
new file mode 100644
index 0000000..cbf6293
--- /dev/null
+++ b/dlls/sapi/sapi.rc
@@ -0,0 +1,22 @@
+/*
+ * Speech API (SAPI) resource file.
+ *
+ * Copyright (C) 2017 Huw Davies
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
+ */
+
+/* @makedep: sapi.rgs */
+1 WINE_REGISTRY sapi.rgs
diff --git a/dlls/sapi/sapi.rgs b/dlls/sapi/sapi.rgs
new file mode 100644
index 0000000..b086303
--- /dev/null
+++ b/dlls/sapi/sapi.rgs
@@ -0,0 +1,15 @@
+HKLM
+{
+ NoRemove Software
+ {
+ NoRemove Microsoft
+ {
+ NoRemove Speech
+ {
+ NoRemove Voices
+ {
+ }
+ }
+ }
+ }
+}
diff --git a/tools/sfnt2fon/sfnt2fon.c b/tools/sfnt2fon/sfnt2fon.c
index ea915da..25f0763 100644
--- a/tools/sfnt2fon/sfnt2fon.c
+++ b/tools/sfnt2fon/sfnt2fon.c
@@ -439,9 +439,9 @@ static struct fontinfo *fill_fontinfo( const char *face_name, int ppem, int enc,
el = 0;
first_char = FT_Get_First_Char(face, &gi);
- if(first_char == 0xd) /* fontforge's first glyph is 0xd, we'll catch this and skip it */
- first_char = 32; /* FT_Get_Next_Char for some reason returns too high
- number in this case */
+ if(first_char < 0x20) /* Ignore glyphs below 0x20 */
+ first_char = 0x20; /* FT_Get_Next_Char for some reason returns too high
+ number in this case */
info = calloc( 1, sizeof(*info) );
Module: wine
Branch: master
Commit: 35347b0e406eb2bba6feef217da3fc11b3e66232
URL: http://source.winehq.org/git/wine.git/?a=commit;h=35347b0e406eb2bba6feef217…
Author: Huw Davies <huw(a)codeweavers.com>
Date: Wed Sep 27 10:17:18 2017 +0100
sapi: Create the Voices registry key.
Signed-off-by: Huw Davies <huw(a)codeweavers.com>
Signed-off-by: Alexandre Julliard <julliard(a)winehq.org>
---
dlls/sapi/Makefile.in | 3 +++
dlls/sapi/sapi.rc | 22 ++++++++++++++++++++++
dlls/sapi/sapi.rgs | 15 +++++++++++++++
3 files changed, 40 insertions(+)